@@ -22,19 +22,22 @@
 #include <qstringlist.h>
 #include <qstring.h>
 #include <qwidget.h>
+//Added by qt3to4:
+#include <QShowEvent>
+#include <QFrame>
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
-#include "kommander_export.h"
+#include "kommanderwidgets_export.h"
 
 /* Forward Decls */
 class QTextEdit;
 class QFrame;
 class QToolButton;
-class QHButtonGroup;
+class QGroupBox;
 
 class QShowEvent;
-class KOMMANDER_EXPORT RichTextEditor : public QWidget, public KommanderWidget
+class KOMMANDERWIDGETS_EXPORT RichTextEditor : public QWidget, public KommanderWidget
 {
 	Q_OBJECT
 
@@ -52,23 +55,28 @@ public:
   virtual QString populationText() const;
   virtual void setPopulationText(const QString&);
   
-  virtual QString handleDCOP(int function, const QStringList& args);
+  virtual QString handleDBUS(int function, const QStringList& args);
+  using KommanderWidget::handleDBUS;
   virtual bool isFunctionSupported(int function);
 public slots:
   void setTextChanged();
   void setWidgetText(const QString &);
-  void textAlign(int);
+  void textAlignLeft(bool);
+  void textAlignRight(bool);
+  void textAlignCenter(bool);
   void textBold(bool);
   void textUnder(bool);
   void textItalic(bool);
   void fontChanged(const QFont &);
-  void alignmentChanged(int);
+  void cursorPositionChanged();
   virtual void populate();
 signals:
   void widgetOpened();
   void widgetTextChanged(const QString&);
+  void contextMenuRequested(int xpos, int ypos);
 protected:
-    void showEvent( QShowEvent *e );
+  void showEvent( QShowEvent *e );
+  void contextMenuEvent( QContextMenuEvent * e );
 private:
   QFrame *m_toolbar;
   QTextEdit *m_textedit;
@@ -76,7 +84,7 @@ private:
   QToolButton *m_buttonTextBold, *m_buttonTextUnder, *m_buttonTextItalic, 
     *m_buttonTextLeft,  *m_buttonTextCenter, *m_buttonTextRight;
 
-  QHButtonGroup *m_formatGroup, *m_alignGroup;
+  QGroupBox *m_formatGroup, *m_alignGroup;
 
 };
 
