@@ -1,20 +1,25 @@
 
-/***************************************************************************
-                          debugXSL.c  - debugger commands to use
-                             -------------------
-    begin                : Sun Sep 16 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 /*
  * Orinal file : debugXML.c : This is a set of routines used for 
@@ -30,16 +35,11 @@
  * stylesheet source, xml data, stylesheet variables
  */
 
-#ifdef WIN32
-#include <wtypes.h>
-#include <winbase.h>            /* needed fort the sleep function */
-#endif
-
+#include "debugXSL.h"
 #include "xsldbg.h"
 #include "files.h"
 #include "cmds.h"               /* list of command Id's */
 #include "debug.h"
-#include "debugXSL.h"
 #include "options.h"
 #include "breakpoint.h"
 #include "help.h"
@@ -47,8 +47,23 @@
 #include <libxslt/transform.h>  /* needed by source command */
 #include <libxslt/xsltInternals.h>
 #include <libxml/debugXML.h>
+#include <libxml/parser.h>
+#include <libxml/parserInternals.h>
+#include <kconfig.h>
+#include <kconfiggroup.h>
+#include <ksharedptr.h>
+#include <kglobal.h>
+
+#ifdef HAVE_USLEEP
+#include <unistd.h>
+#endif
 #include <stdio.h>
 
+#ifdef WIN32
+#include <wtypes.h>
+#include <winbase.h>            /* needed fort the sleep function */
+#endif
+
 /* language change support */
 #ifdef LOCALE_PREFIX
 #include <locale.h>
@@ -164,6 +179,12 @@ const char *commandNames[] = {
     /* language change */
     "lang",
 
+    /* read settings */
+    "readconfig",
+
+    /* read settings */
+    "writeconfig",
+
     NULL                        /* Indicate the end of list */
 };
 
@@ -214,7 +235,7 @@ const char *shortCommandNames[] = {
     /* file related */
     /* "output", already listed */
     "ent",                      /* entities command */
-    "sys",                      /* sytem command */
+    "sys",                      /* system command */
     "pub",                      /* public command */
     "encoding",
     "validate",
@@ -251,6 +272,12 @@ const char *shortCommandNames[] = {
     /* language change */
     "lang",
 
+    /* read settings */
+    "readconfig",
+
+    /* read settings */
+    "writeconfig",
+
     NULL                        /* Indicate the end of list */
 };
 
@@ -309,157 +336,50 @@ enum ShortcutsEnum {
  -------------------------------------------*/
 
 
-/* xslDbgCd :
- * Change directories
- * @styleCtxt : current stylesheet context
- * @ctxt : current shell context
- * @arg : path to change to
- * @source : is valid
- *
- * Returns 1 on success,
- *         0 otherwise
- */
 int xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
-             xmlChar * arg, xmlNodePtr source);
+        xmlChar * arg, xmlNodePtr source);
 
 
-/**
- * xslDbgPrintCallStack:
- * @arg : the number of frame to print, NULL if all items 
- * 
- * Print all items found on the callStack
- *
- * Returns 1 on success,
- *         0 otherwise
- */
 int xslDbgPrintCallStack(const xmlChar * arg);
 
 
-/**
- * xslDbgSleep:
- * @delay : the number of microseconds to delay exection by
- *
- * Delay execution by a specified number of microseconds. On some system 
- *      this will not be at all accurate.
- */
 void xslDbgSleep(long delay);
 
 
-/**
- * xslDbgWalkContinue:
- *
- * Delay execution for time as indicated by OPTION_WALK_SPEED
- * Can only be called from within shellPrompt!
- * OPTION_WALK_SPEED != WALKSPEED_STOP
- *
- * Returns 1 if walk is to continue,
- *         0 otherwise
- */
 int xslDbgWalkContinue(void);
 
 
 
-/**
- * addBreakPointNode:
- * @payload : valid breakPointPtr
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-  addBreakPointNode(void *payload, void *data,
-                    xmlChar * name);
+void addBreakPointNode(void *payload, void *data,
+        xmlChar * name);
 
 
-/**
- * addSourceNode:
- * @payload : valid xsltStylesheetPtr
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-  addSourceNode(void *payload, void *data,
-                xmlChar * name);
+void addSourceNode(void *payload, void *data,
+        xmlChar * name);
 
 
-/**
- * addTemplateNode:
- * @payload : valid xsltTemplatePtr
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-  addTemplateNode(void *payload, void *data,
-                  xmlChar * name);
+void addTemplateNode(void *payload, void *data,
+        xmlChar * name);
 
-/**
- * addGlobalNode:
- * @payload : valid xmlNodePtr of global variable
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-  addGlobalNode(void *payload, void *data,
-                xmlChar * name);
+void addGlobalNode(void *payload, void *data,
+        xmlChar * name);
 
-/**
- * addLocalNode:
- * @payload : valid xmlNodePtr of local variable
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-  addLocalNode(void *payload, void *data,
-               xmlChar * name);
+void addLocalNode(void *payload, void *data,
+        xmlChar * name);
 
 
-/**
- * addIncludeNode:
- * @payload : valid xmlNodePtr of include instuction
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-  addIncludeNode(void *payload, void *data,
-                 xmlChar * name);
+void addIncludeNode(void *payload, void *data,
+        xmlChar * name);
 
 
 
-/**
- * addCallStackItems:
- * 
- * Convert call stack items into format needed, and add to search dataBase 
- */
-void
-  addCallStackItems(void);
+void addCallStackItems(void);
 
 
-/**
- *  shellPrompt:
- * @source: The current stylesheet instruction being executed
- * @doc: The current document node being processed
- * @filename: Not used
- * @input: The function to call to when reading commands from stdio
- * @output: Where to put the results
- * @styleCtxt: Is valid 
- *
- * Present to the user the xsldbg shell
- */
 void shellPrompt(xmlNodePtr source, xmlNodePtr doc,
-                 xmlChar * filename,
-                 xmlShellReadlineFunc input,
-                 FILE * output, xsltTransformContextPtr styleCtxt);
+        xmlChar * filename,
+        xmlShellReadlineFunc input,
+        FILE * output, xsltTransformContextPtr styleCtxt);
 
 /* ------------------------------------- 
     End private functions
@@ -467,15 +387,7 @@ void shellPrompt(xmlNodePtr source, xmlNodePtr doc,
 
 
 
-/**
- * debugXSLGetTemplate:
- * 
- * Return the last template node found, if an
- *
- * Returns The last template node found, if any
- */
-xsltTemplatePtr
-debugXSLGetTemplate(void)
+xsltTemplatePtr debugXSLGetTemplate(void)
 {
     return rootCopy;
 }
@@ -488,18 +400,7 @@ debugXSLGetTemplate(void)
  ****************************************************************/
 
 
-/* xslDbgCd :
- * Change directories
- * @styleCtxt : current stylesheet context
- * @ctxt : current shell context
- * @arg : path to change to and in UTF-8
- * @source : is valid 
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
+int xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
          xmlChar * arg, xmlNodePtr source)
 {
     xmlXPathObjectPtr list = NULL;
@@ -523,16 +424,16 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
 
                     /* quickly find a template */
                     /* skip any white spaces */
-                    while (_IS_BLANK(arg[offset]))
+                    while(arg[offset] == ' ')
                         offset++;
 
                     templateNode =
                         findTemplateNode(styleCtxt->style, &arg[offset]);
                     if (!templateNode) {
-                        xsldbgGenericErrorFunc(i18n("Error: The XSLT template named \"%1\" was not found.\n").arg(xsldbgText(&arg[offset])));
+                        xsldbgGenericErrorFunc(i18n("Error: The XSLT template named \"%1\" was not found.\n", xsldbgText(&arg[offset])));
                         return result;
                     } else {
-                        xsldbgGenericErrorFunc(i18n(" template: \"%1\"\n").arg(xsldbgText(&arg[offset])));
+                        xsldbgGenericErrorFunc(i18n(" template: \"%1\"\n", xsldbgText(&arg[offset])));
                         ctxt->node = templateNode;
                         result = 1;
                         return result;
@@ -560,7 +461,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                         xsldbgGenericErrorFunc(i18n("Error: Unable to cd. No stylesheet loaded.\n"));
                     }
                 } else {
-                    xsldbgGenericErrorFunc(i18n("Error: Unknown arguments to the command %1.\n").arg("cd"));
+                    xsldbgGenericErrorFunc(i18n("Error: Unknown arguments to the command %1.\n", QString("cd")));
                 }
             } else
                 xsldbgGenericErrorFunc(i18n("Error: Unable to cd. No stylesheet loaded.\n"));
@@ -582,7 +483,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                                        XSLT_NAMESPACE);
                 list = xmlXPathEval((xmlChar *) arg, ctxt->pctxt);
             } else {
-                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to the command %1.\n").arg("cd"));
+                xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to the command %1.\n", QString("cd")));
             }
         }
 
@@ -603,9 +504,9 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                             }
                             result = 1;
                         } else
-                            xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is a Node Set with %n child.", "Warning: XPath %1 is a Node Set with %n children.", list->nodesetval->nodeNr).arg(xsldbgText(arg)) + QString("\n"));
+                            xsldbgGenericErrorFunc(i18np("Warning: XPath %2 is a Node Set with %1 child.", "Warning: XPath %2 is a Node Set with %1 children.", list->nodesetval->nodeNr, xsldbgText(arg)) + QString("\n"));
                     } else {
-                        xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is an empty Node Set.\n").arg(xsldbgText(arg)));
+                        xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is an empty Node Set.\n", xsldbgText(arg)));
                     }
                     break;
 
@@ -614,26 +515,15 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
             }
             xmlXPathFreeObject(list);
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: XPath %1 was not found.\n").arg(xsldbgText(arg)));
+            xsldbgGenericErrorFunc(i18n("Error: XPath %1 was not found.\n", xsldbgText(arg)));
         }
-        if (ctxt->pctxt)
-          ctxt->pctxt->node = NULL;
+        ctxt->pctxt->node = NULL;
     }
     return result;
 }
 
 
-/**
- * xslDbgPrintCallStack:
- * @arg : the number of frame to print, NULL if all items 
- * 
- * Print all items found on the callStack
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-xslDbgPrintCallStack(const xmlChar * arg)
+int xslDbgPrintCallStack(const xmlChar * arg)
 {
     int depth = 0;
     int result = 1;
@@ -669,12 +559,12 @@ xslDbgPrintCallStack(const xmlChar * arg)
 			    if (rootNameTemp && rootModeTemp){
 			      if (rootCopy->match)
 			        /* display information about the current XSLT template */
-                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg(xsldbgText(rootCopy->match)).arg(xsldbgText(rootModeTemp)));
+                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"", depth, xsldbgText(rootCopy->match), xsldbgText(rootModeTemp)));
 			      else
 			        /* display information about the current XSLT template */
-                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg(xsldbgText(rootNameTemp)).arg(xsldbgText(rootModeTemp)));
+                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"", depth, xsldbgText(rootNameTemp), xsldbgText(rootModeTemp)));
 			      /* display where we are in the source/document file */	
-			      xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
+			      xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n", xsldbgUrl(curUrl), curLine));
 			    }else{
 			      xsldbgGenericErrorFunc(i18n("Error: Out of memory.\n"));
 			      result = 0;
@@ -689,9 +579,9 @@ xslDbgPrintCallStack(const xmlChar * arg)
 			    }
                         } else if (curUrl) {
 			    /* display information about the current XSLT template */
-                            xsldbgGenericErrorFunc(i18n("#%1 template: \"LIBXSLT_DEFAULT\" mode: \"\"").arg(depth));
+                            xsldbgGenericErrorFunc(i18n("#%1 template: \"LIBXSLT_DEFAULT\" mode: \"\"", depth));
 			    /* display where we are in the source/document file */	
-                            xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
+                            xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n", xsldbgUrl(curUrl), curLine));
                         }
                         if (curUrl)
                             xmlFree(curUrl);
@@ -703,10 +593,10 @@ xslDbgPrintCallStack(const xmlChar * arg)
 					 callPointItem->info->modeName);
 		    if (nameTemp && modeTemp){
 		      /* display information about the current XSLT template */
-		      xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth - 1).arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
+		      xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"", depth - 1, xsldbgText(nameTemp), xsldbgText(modeTemp)));
 		      if (callPointItem->info->url)
 			/* display where we are in the source/document file */	
-                        xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(callPointItem->info->url)).arg(callPointItem->lineNo));
+                        xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n", xsldbgUrl(callPointItem->info->url), callPointItem->lineNo));
 		      else
                         xsldbgGenericErrorFunc("\n");
 		    }else{
@@ -755,11 +645,11 @@ xslDbgPrintCallStack(const xmlChar * arg)
             callPointItem = callStackGet(templateDepth + 1);
             if (callPointItem && callPointItem->info) {
 		/* display information about the current XSLT template */
-                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\"").arg(templateDepth).arg(xsldbgText(callPointItem->info->templateName)));
+                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\"", templateDepth, xsldbgText(callPointItem->info->templateName)));
                 /* should alays be present but .. */
                 if (callPointItem->info->url)
 		    /* display where we are in the source/document file */	
-                    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(callPointItem->info->url)).arg(callPointItem->lineNo));
+                    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n", xsldbgUrl(callPointItem->info->url), callPointItem->lineNo));
                 else
                     xsldbgGenericErrorFunc("\n");
             } else {
@@ -775,15 +665,7 @@ xslDbgPrintCallStack(const xmlChar * arg)
 }
 
 
-/**
- * xslDbgSleep:
- * @delay : the number of microseconds to delay exection by
- *
- * Delay execution by a specified number of microseconds. On some system 
- *      this will not be at all accurate.
- */
-void
-xslDbgSleep(long delay)
+void xslDbgSleep(long delay)
 {
 #ifdef HAVE_USLEEP
     usleep(delay);
@@ -806,22 +688,11 @@ xslDbgSleep(long delay)
 }
 
 
-/**
- * xslDbgWalkContinue:
- *
- * Delay execution for time as indicated by OPTION_WALK_SPEED
- * Can only be called from within shellPrompt!
- * OPTION_WALK_SPEED != WALKSPEED_STOP
- *
- * Returns 1 if walk is to continue,
- *         0 otherwise
- */
-int
-xslDbgWalkContinue(void)
+int xslDbgWalkContinue(void)
 {
     int result = 0, speed = optionsGetIntOption(OPTIONS_WALK_SPEED);
 
-    /* We need to ensure that output is realy sent. Otherwise
+    /* We need to ensure that output is really sent. Otherwise
      * walking using xemacs under WIN32 will not work */
     fflush(stderr);
 
@@ -850,16 +721,7 @@ xslDbgWalkContinue(void)
 }
 
 
-/**
- * addBreakPointNode:
- * @payload : valid breakPointPtr
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-addBreakPointNode(void *payload, void *data,
+void addBreakPointNode(void *payload, void *data,
                   xmlChar * name)
 {
     Q_UNUSED(data);
@@ -870,16 +732,7 @@ addBreakPointNode(void *payload, void *data,
 }
 
 
-/**
- * addSourceNode:
- * @payload : valid xsltStylesheetPtr
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-addSourceNode(void *payload, void *data,
+void addSourceNode(void *payload, void *data,
               xmlChar * name)
 {
     Q_UNUSED(data);
@@ -890,16 +743,7 @@ addSourceNode(void *payload, void *data,
 }
 
 
-/**
- * addTemplateNode:
- * @payload : valid xsltTemplatePtr
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-addTemplateNode(void *payload, void *data,
+void addTemplateNode(void *payload, void *data,
                 xmlChar * name)
 {
     Q_UNUSED(data);
@@ -910,16 +754,7 @@ addTemplateNode(void *payload, void *data,
 }
 
 
-/**
- * addGlobalNode:
- * @payload : valid xmlNodePtr of global variable
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-addGlobalNode(void *payload, void *data,
+void addGlobalNode(void *payload, void *data,
               xmlChar * name)
 {
     Q_UNUSED(data);
@@ -930,16 +765,7 @@ addGlobalNode(void *payload, void *data,
 }
 
 
-/**
- * addLocalNode:
- * @payload : valid xmlNodePtr of local variable
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-addLocalNode(void *payload, void *data,
+void addLocalNode(void *payload, void *data,
              xmlChar * name)
 {
     Q_UNUSED(data);
@@ -950,16 +776,7 @@ addLocalNode(void *payload, void *data,
 }
 
 
-/**
- * addIncludeNode:
- * @payload : valid xmlNodePtr of include instuction
- * @data : not used
- * @name : not used
- * 
- * Convert payload into format needed, and add to search dataBase 
- */
-void
-addIncludeNode(void *payload, void *data,
+void addIncludeNode(void *payload, void *data,
                xmlChar * name)
 {
     Q_UNUSED(data);
@@ -970,13 +787,7 @@ addIncludeNode(void *payload, void *data,
 }
 
 
-/**
- * addCallStackItems:
- * 
- * Convert call stack items into format needed, and add to search dataBase 
- */
-void
-addCallStackItems(void)
+void addCallStackItems(void)
 {
     callPointPtr item;
     xmlNodePtr node;
@@ -993,20 +804,7 @@ addCallStackItems(void)
 }
 
 
-/**
- * updateSearchData:
- * @styleCtxt: Not used
- * @style: Is valid
- * @data: Not used but MUST be NULL for the moment
- * @variableTypes: What types of variables to look
- *
- * Update the searchDatabase
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-updateSearchData(xsltTransformContextPtr styleCtxt,
+int updateSearchData(xsltTransformContextPtr styleCtxt,
                  xsltStylesheetPtr style,
                  void *data, VariableTypeEnum variableTypes)
 {
@@ -1044,25 +842,12 @@ updateSearchData(xsltTransformContextPtr styleCtxt,
 }
 
 
-/**
- * debugXSLBreak:
- * @templ: The source node being executed
- * @node: The data node being processed
- * @root: The template being applied to "node"
- * @ctxt: The transform context for stylesheet being processed
- *
- * A break point has been found so pass control to user
- */
-void
-debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
+void debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
               xsltTransformContextPtr ctxt)
 {
     xmlDocPtr tempDoc = NULL;
     xmlNodePtr tempNode = NULL;
     rootCopy = root;
-    static const xmlChar *lastTemplate = NULL;
-    xmlBufferPtr buffer = xmlBufferCreate();
-    static char mybuff[6] = " 0\n\x0";
 
     if (ctxt && templ && root && !xsldbgReachedFirstTemplate)
 	xsldbgReachedFirstTemplate = true;
@@ -1103,40 +888,19 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
 	  /* we only want messages if we are not
 	    in the process of completing the next command */
 	  if (terminalIO == NULL) {
-
-            if (root->match){
-                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp)));
-		if (lastTemplate != root->match && buffer){
-		    xmlBufferCCat(buffer, "\nreached matched template:");
-		    xmlBufferCat(buffer, root->match); 
-		    xmlBufferCCat(buffer, mybuff);
-		    xsltCopyTextString(ctxt, ctxt->insert,xmlBufferContent(buffer),0);
-		    mybuff[1]++;
-		    lastTemplate = root->match;
-		}
-            }else{
-                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
-		if (lastTemplate != root->name && buffer){
-		    xmlBufferCCat(buffer, "\nreached named template:");
-		    xmlBufferCat(buffer,root->match); 
-		    xmlBufferCCat(buffer,mybuff);
-		    xsltCopyTextString(ctxt, ctxt->insert,xmlBufferContent(buffer),0);
-		    mybuff[1]++;
-		    lastTemplate = root->name;
-		}
-		
-	    }
-	    if (buffer)
-	       xmlBufferFree(buffer);
+            if (root->match)
+                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n", xsldbgText(root->match), xsldbgText(modeTemp)));
+            else
+                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n", xsldbgText(nameTemp), xsldbgText(modeTemp)));
 	  } else {
             if ((xslDebugStatus == DEBUG_TRACE) ||
                 (xslDebugStatus == DEBUG_WALK)) {
 		QString message;
                 if (root->match)
-		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp));
+		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n", xsldbgText(root->match), xsldbgText(modeTemp));
                 else
-		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp));
-		fprintf(terminalIO, "%s", message.local8Bit().data());
+		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n", xsldbgText(nameTemp), xsldbgText(modeTemp));
+		fprintf(terminalIO, "%s", message.toUtf8().constData());
             }
 	  }
 	}
@@ -1155,19 +919,7 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
 
 /* Highly modified function based on xmlShell */
 
-/**
- *  shellPrompt:
- * @source: The current stylesheet instruction being executed
- * @doc: The current document node being processed
- * @filename: Not used
- * @input: The function to call to when reading commands from stdio
- * @output: Where to put the results
- * @styleCtxt: Is valid 
- *
- * Present to the user the xsldbg shell
- */
-void
-shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
+void shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
             xmlShellReadlineFunc input, FILE * output,
             xsltTransformContextPtr styleCtxt)
 {
@@ -1292,9 +1044,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 breakUri = ctxt->node->doc->URL;
 
             if (xmlGetLineNo(ctxt->node) != -1)
-		messageTxt = i18n("Breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(breakUri)).arg(xmlGetLineNo(ctxt->node));
+		messageTxt = i18n("Breakpoint for file \"%1\" at line %2.\n", xsldbgUrl(breakUri), xmlGetLineNo(ctxt->node));
             else
-                messageTxt = i18n("Breakpoint at text node in file \"%1\".\n").arg(xsldbgUrl(breakUri));
+                messageTxt = i18n("Breakpoint at text node in file \"%1\".\n", xsldbgUrl(breakUri));
             if (baseUri != NULL) {
                 xmlFree(baseUri);
                 baseUri = NULL;
@@ -1302,7 +1054,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 
             if (((xslDebugStatus == DEBUG_TRACE) ||
                  (xslDebugStatus == DEBUG_WALK)) && (terminalIO != NULL))
-                fprintf(terminalIO, "%s", messageTxt.utf8().data());
+                fprintf(terminalIO, "%s", messageTxt.toUtf8().constData());
             else
 		xsldbgGenericErrorFunc(messageTxt);
 
@@ -1442,11 +1194,11 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
             nbargs++;
 
 
-        commandId = lookupName(command, (xmlChar **) commandNames);
+        commandId = lookupName((const char*)command, commandNames);
         /* try command shorts if command is not found */
         if (commandId < 0)
             commandId =
-                lookupName(command, (xmlChar **) shortCommandNames);
+                lookupName((const char*)command, shortCommandNames);
 
         cmdResult = -1;         /* flag that it contains no result */
         /*
@@ -1475,7 +1227,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 xslDebugStatus = DEBUG_STEP;
                 exitShell++;
                 cmdResult = 1;
-	        /* Do the the next part of this command
+	        /* Do the next part of this command
 		   which is the up command */
 		nextCommandActive = 1;
 	     break;
@@ -1612,7 +1364,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                     if (printCount == 0)
                         xsldbgGenericErrorFunc(i18n("\nNo breakpoints are set for the file.\n"));
                     else
-                        xsldbgGenericErrorFunc(i18n("\tTotal of %n breakpoint present.","\tTotal of %n breakpoints present.", printCount) + QString("\n"));
+                        xsldbgGenericErrorFunc(i18np("\tTotal of %1 breakpoint present.","\tTotal of %1 breakpoints present.", printCount) + QString("\n"));
                 }
                 cmdResult = 1;
                 break;
@@ -1706,7 +1458,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		  if(tempBaseName){
 		    xsldbgGenericErrorFunc("\n");
 		    xsldbgGenericErrorFunc((char*)dir);
-		    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2").arg(xsldbgUrl(tempBaseName)).arg(xmlGetLineNo(ctxt->node)));
+		    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2", xsldbgUrl(tempBaseName), xmlGetLineNo(ctxt->node)));
 		    xmlFree(tempBaseName);
 		    cmdResult = 1;
 		  }
@@ -1741,7 +1493,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 
             case DEBUG_LOCALS_CMD:
                 if (loadedFiles == 0)
-                    /* if gdb compatability mode is enable print the globals then 
+                    /* if gdb compatibility mode is enable print the globals then 
                      * the locals */
                     if (optionsGetIntOption(OPTIONS_GDB) == 1) {
                         cmdResult =
@@ -1788,16 +1540,14 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                         break;
                 } else {
                     /* load new stylesheet file, actual loading happens later */
-                    xmlChar *expandedName = filesExpandName(arg);
+                    QString expandedName = filesExpandName(xsldbgText(arg));
 
-                    if (expandedName) {
+                    if (!expandedName.isEmpty()) {
                         xsldbgGenericErrorFunc(i18n("Load of source deferred. Use the run command.\n"));
 
-                        optionsSetStringOption(OPTIONS_SOURCE_FILE_NAME,
-                                               expandedName);
+                        optionsSetStringOption(OPTIONS_SOURCE_FILE_NAME, expandedName);
 			notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
                         loadedFiles = 1;
-                        xmlFree(expandedName);
                         cmdResult = 1;
                     } else {
                         cmdResult = 0;
@@ -1828,16 +1578,15 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                         break;
                 } else {
                     /* load new xml file actual loading hapens later */
-                    xmlChar *expandedName = filesExpandName(arg);
+                    QString expandedName = filesExpandName(xsldbgText(arg));
 
-                    if (expandedName) {
+                    if (!expandedName.isEmpty()) {
                         xsldbgGenericErrorFunc(i18n("Load of data file deferred. Use the run command.\n"));
 
                         optionsSetStringOption(OPTIONS_DATA_FILE_NAME,
                                                expandedName);
 			notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
                         loadedFiles = 1;
-                        xmlFree(expandedName);
                         cmdResult = 1;
                     } else {
                         cmdResult = 0;
@@ -1854,7 +1603,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 /* use dir as a working buffer */
                 xmlStrnCpy(dir, arg, 2);
                 dir[2] = '\0';
-                shortCutId = lookupName(dir, (xmlChar **) cdShortCuts);
+                shortCutId = lookupName((const char*)dir, cdShortCuts);
                 if (shortCutId >= 0) {
                     if (xmlStrLen(arg) == 2) {
                         cmdResult = xslDbgCd(styleCtxt, ctxt, (xmlChar *)
@@ -1885,7 +1634,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		if (splitString(arg, 1, &systemID) == 1){
 		  cmdResult = xslDbgSystem(systemID);
 		}else{
-		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("system"));
+		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n", QString("system")));
 		}
 	       }
                 break;
@@ -1898,7 +1647,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		if (splitString(arg, 1, &publicID) == 1){
 		  cmdResult = xslDbgPublic(publicID);
 		}else{
-		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("public"));
+		  xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n", QString("public")));
 		}
 	       }
                 break;
@@ -1908,28 +1657,15 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             case DEBUG_VALIDATE_CMD:
-                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").arg("validate"));
+                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n", QString("validate")));
                 cmdResult = 0;
                 /*
                  * xmlShellValidate(ctxt, arg, NULL, NULL);
                  */
                 break;
 
-            case DEBUG_LOAD_CMD:
-                cmdResult = optionsLoad();
-                /* restart xsldbg and activate new configuration */
-                if (cmdResult == 1) {
-                    xslDebugStatus = DEBUG_RUN_RESTART;
-                    exitShell++;
-                }
-                break;
-
-            case DEBUG_SAVE_CMD:
-                cmdResult = optionsSave();
-                break;
-
             case DEBUG_WRITE_CMD:
-                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").arg("write"));
+                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n", QString("write")));
                 cmdResult = 0;
                 /*
                  * xmlShellWrite(ctxt, arg, NULL, NULL);
@@ -1937,7 +1673,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             case DEBUG_FREE_CMD:
-                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n").arg("free"));
+                xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled.\n", QString("free")));
                 cmdResult = 0;
                 /*
                  * if (arg[0] == 0) {
@@ -1976,7 +1712,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 
 
 
-                /* option related commmands */
+                /* option related commands */
             case DEBUG_SETOPTION_CMD:
                 cmdResult = xslDbgShellSetOption(arg);
                 break;
@@ -1993,7 +1729,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		  /* gdb does to say anything after redirecting its 
 		     output */
 		  if (optionsGetIntOption(OPTIONS_GDB) < 2)
-                    xsldbgGenericErrorFunc(i18n("Opening terminal %1.\n").arg(xsldbgText(arg)));
+                    xsldbgGenericErrorFunc(i18n("Opening terminal %1.\n", xsldbgText(arg)));
                     cmdResult = 1;
                 } else
                     cmdResult = 0;
@@ -2009,11 +1745,11 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		    bindtextdomain("kdewebdev/xsldbg", LOCALE_PREFIX);
 		    cmdResult = 1;
 		}else{
-		    xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n").arg("lang"));
+		    xsldbgGenericErrorFunc(i18n("Error: Missing arguments for the command %1.\n", QString("lang")));
 		    cmdResult = 0;
 		}
 #else
-	        xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled\n").arg("lang"));
+	        xsldbgGenericErrorFunc(i18n("Warning: The %1 command is disabled\n", QString("lang")));
 		cmdResult = 1;
 #endif
 		break;
@@ -2058,7 +1794,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 	       break;
 
 	     default:
-	        xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n").arg("showmatch")); 
+	        xsldbgGenericErrorFunc(i18n("Error: Invalid arguments for the command %1.\n", QString("showmatch"))); 
 	     }
            break;
  
@@ -2076,8 +1812,21 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 cmdResult = xslDbgShellSetVariable(styleCtxt, arg);
                 break;
 
+            case DEBUG_LOAD_CMD:
+            case DEBUG_READCONFIG_CMD:
+                if (xsldbgReadConfig(arg)){
+                    cmdResult = 1;
+                    xslDebugStatus = DEBUG_RUN_RESTART;
+                }
+                break;
+
+            case DEBUG_SAVE_CMD:
+            case DEBUG_WRITECONFIG_CMD:
+                if (xsldbgWriteConfig(arg))
+                    cmdResult = 1;
+                break;
             default:
-                xsldbgGenericErrorFunc(i18n("Error: Unknown command %1. Try help.\n").arg(xsldbgText(command)));
+                xsldbgGenericErrorFunc(i18n("Error: Unknown command %1. Try help.\n", xsldbgText(command)));
                 cmdResult = 0;
         }
 
@@ -2088,9 +1837,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		ctxt->node->doc && ctxt->node->doc->URL) {
 
                 if (xmlGetLineNo(ctxt->node) != -1)
-                    xsldbgGenericErrorFunc(i18n("Breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(ctxt->node->doc->URL)).arg(xmlGetLineNo(ctxt->node)));
+                    xsldbgGenericErrorFunc(i18n("Breakpoint for file \"%1\" at line %2.\n", xsldbgUrl(ctxt->node->doc->URL), xmlGetLineNo(ctxt->node)));
                 else
-                    xsldbgGenericErrorFunc(i18n("Breakpoint at text node in file \"%1\".\n").arg(xsldbgUrl(ctxt->node->doc->URL)));
+                    xsldbgGenericErrorFunc(i18n("Breakpoint at text node in file \"%1\".\n", xsldbgUrl(ctxt->node->doc->URL)));
             }
         }
 
