@@ -71,7 +71,7 @@ QString XsldbgParamModel::getName(int row)
         if (param) {
             result = param->text();
         }else {
-            qWarning("%s item not retrieved", __PRETTY_FUNCTION__);
+            qWarning("XsldbgParamModel::getName item not retrieved");
         }
     }
 
@@ -87,7 +87,7 @@ QString XsldbgParamModel::getValue(int row)
         if (param) {
             result = param->text();
         }else {
-            qWarning("%s item not retrieved", __PRETTY_FUNCTION__);
+            qWarning("XsldbgParamModel::getValue item not retrieved");
         }
     }
 
